from django.apps import AppConfig


class CsvDownloadConfig(AppConfig):
    name = "django_csv"
    verbose_name = "CSV Downloads"
    default_auto_field = "django.db.models.AutoField"
